@@ -1,8 +1,4 @@
-package OpenResty::Backend::Pg;
-
-use strict;
-use warnings;
-
+package OpenResty::Backend::Pg; use strict; use warnings; 
 #use Smart::Comments;
 use DBI;
 use OpenResty::SQL::Select;
@@ -146,10 +142,14 @@ sub set_user {
 }
 
 sub add_user {
-    my $self = shift;
-    my $user = shift;
-    $self->add_empty_user($user);
-    $self->SUPER::add_user($user, @_);
+    my ($self, $user, $password, $has_schema) = @_;
+    if ($has_schema) {
+       die "Schema $user not found.\n" if !$self->has_user($user);
+       $self->add_schema_user($user);
+    } else {
+        $self->add_empty_user($user);
+    }
+    $self->SUPER::add_user($user, $password);
 }
 
 sub add_empty_user {
@@ -160,6 +160,13 @@ set search_path to $user;
 _EOC_
 }
 
+sub add_schema_user {
+    my ($self, $user) = @_;
+    $self->do(<<"_EOC_");
+set search_path to $user;
+_EOC_
+}
+
 sub drop_user {
     my ($self, $user) = @_;
     $self->SUPER::drop_user($user);
